darkhistory.physics.coll_ion_sec_elec_spec — DarkHistory documentation

# darkhistory.physics.coll_ion_sec_elec_spec

`darkhistory.physics.` `coll_ion_sec_elec_spec`(in_eng, eng, species=None)

  Secondary electron spectrum after collisional ionization.

  See 0910.4410.

  Parameters: | in_eng : float The incoming electron energy. eng : ndarray Abscissa of kinetic energies. species : {‘HI’, ‘HeI’, ‘HeII’} Species of interest.
  Returns: | ndarray Secondary electron spectrum. Total number of electrons = 2.

  Notes

  Includes both the freed and initial electrons. Conservation of energy is not enforced, but number of electrons is.

#### Previous topic

darkhistory.physics.coll_exc_xsec

#### Next topic

darkhistory.physics.coll_ion_xsec

### This Page

Show Source